# pytket-projectq

[Pytket](https://cqcl.github.io/pytket) is a Python module for interfacing
with CQC t|ket>, a set of quantum programming tools.

[ProjectQ](https://github.com/ProjectQ-Framework/ProjectQ) is an open-source
library for quantum circuit compilation and simulation.

`pytket-projectq` is an extension to `pytket` that allows `pytket` circuits to
be run on ProjectQ simulators, as well as conversion to the ProjectQ
representation.

## Getting started

`pytket-projectq` is available for Python 3.6, 3.7 and 3.8, on Linux, MacOS and Windows.
To install, run:

```pip install pytket-projectq```

## LICENCE

Copyright 2019-2020 Cambridge Quantum Computing

Pytket is licensed under a Non-Commercial Use Software Licence (the "Licence");
you may not use this product except in compliance with the Licence. You may view
the License [here](https://cqcl.github.io/pytket/build/html/licence.html).

Unless required by applicable law or agreed to in writing, software distributed
under the Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the Licence for the
specific language governing permissions and limitations under the Licence, but
note it is strictly for non-commercial use.
